@@ -1,5 +1,8 @@
-/*  libtifiles - TI File Format library
- *  Copyright (C) 2002-2003  Romain Lievin
+/* Hey EMACS -*- linux-c -*- */
+/* $Id: types73.h 3521 2007-06-26 10:22:27Z roms $ */
+
+/*  libtifiles - file format library, a part of the TiLP project
+ *  Copyright (C) 1999-2005  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -19,30 +22,36 @@
 #ifndef __TIFILES_DEFS73__
 #define __TIFILES_DEFS73__
 
-#include "stdints.h"
+#include "stdints2.h"
 
 #define TI73_MAXTYPES 48
 
 #define TI73_REAL   0x00
 #define TI73_LIST   0x01
-#define TI73_MATRX  0x02
+#define TI73_MATRX  0x02	//deprecated
+#define TI73_MAT	0x02
 #define TI73_EQU    0x03
-#define TI73_STRNG  0x04
+#define TI73_STRNG  0x04	//deprecated
+#define TI73_STR	0x04
 #define TI73_PRGM   0x05
 #define TI73_ASM    0x06
 #define TI73_PIC    0x07
 #define TI73_GDB    0x08
 #define TI73_CPLX   0x0C
-#define TI73_WDW    0x0F
+#define TI73_WDW    0x0F	//deprecated
+#define TI73_WINDW	0x0F
 #define TI73_ZSTO   0x10
-#define TI73_TAB    0x11
+#define TI73_TAB    0x11	//deprecated
+#define TI73_TABLE	0x11
 #define TI73_BKUP   0x13
 
 
 #define TI73_DIR    0x19
+#define TI73_AVAR	0x1A
 #define TI73_AMS    0x23
 #define TI73_APPL   0x24
 #define TI73_IDLIST 0x26
+#define TI73_CLK	0x29
 
 // libtifiles: for internal use only, not exported !
 
