@@ -1,5 +1,8 @@
-/*  libtifiles - TI File Format library
- *  Copyright (C) 2002-2003  Romain Lievin
+/* Hey EMACS -*- linux-c -*- */
+/* $Id: typesxx.h 3962 2007-10-27 19:11:58Z roms $ */
+
+/*  libtifiles - file format library, a part of the TiLP project
+ *  Copyright (C) 1999-2005  Romain Lievin
  *
  *  This program is free software; you can redistribute it and/or modify
  *  it under the terms of the GNU General Public License as published by
@@ -23,11 +26,14 @@
 #include "types82.h"
 #include "types83.h"
 #include "types83p.h"
+#include "types84p.h"
 #include "types85.h"
 #include "types86.h"
 #include "types89.h"
+#include "types89t.h"
 #include "types92.h"
 #include "types92p.h"
 #include "typesv2.h"
+#include "typesnsp.h"
 
 #endif
